@@ -100,10 +100,7 @@ void	init_chr( void )
 {
 	init_mnstr();
 	init_party();
-
-#ifndef	NDEBUG
 	init_party_debug();
-#endif
 }
 
 /**/
@@ -912,13 +909,16 @@ bool_t	can_move_chr( chr_t *chr, long x, long y )
 
 /**/
 
-void	die_chr( chr_t *p )
+void	die_chr( chr_t *p, bool_t flg_add_exp )
 {
 	dun_t	*dun;
 	long	x, y;
 
 	if( p == NULL )
 		return;
+	if( flg_add_exp && (p->kind == CHR_KIND_MNSTR) )
+		if( p->mnstr_tab != NULL )
+			exp_party( p->mnstr_tab->exp, TRUE );
 
 	x = p->x;
 	y = p->y;
