@@ -2,16 +2,16 @@
 #define	__CHR_H__
 
 #include	"dun.h"
+#include	"resi.h"
+#include	"mnstr_kind.h"
+#include	"fight.h"
 #include	"fx.h"
 
-#define	MBR_MAX_N	6
-#define	MBR_NO_POS	(-1)
-
 #define	ROLL_BASE	0
 
+#define	CHR_NAME_MAX_LEN	80
 #define	MBR_NAME_MAX_LEN	16
 #define	MNSTR_NAME_MAX_LEN	80
-#define	CHR_NAME_MAX_LEN	80
 
 #define	RACE_STR_MAX_LEN	32
 #define	RACE_NAME_MAX_LEN	16
@@ -19,6 +19,7 @@
 #define	ABL_RATE_MIN_N	0
 #define	ABL_RATE_MAX_N	20
 
+typedef unsigned long	flg_chr_t;
 #define	FLG_CHR_AUTO_FIGHT	(1 << 0)
 #define	FLG_CHR_AUTO_DOOR	(1 << 1)
 #define	FLG_CHR_AVOID_TRAP	(1 << 2)
@@ -26,6 +27,7 @@
 #define	FLG_CHR_AUTO_MARK_CONT	(1 << 8)
 #define	FLG_CHR_AUTO_CLR_ACT	(1 << 9)
 
+typedef unsigned long	flg_stat_t;
 #define	FLG_STAT_NULL	0
 #define	FLG_STAT_NOT_EXIST	(1 << 0)
 #define	FLG_STAT_DEAD	(1 << 1)
@@ -46,6 +48,7 @@
 #define	FLG_STAT_DRUNK	(1 << 16)
 #define	FLG_STAT_CAUGHT	(1 << 17)
 
+typedef unsigned long	flg_work_t;
 #define	FLG_WORK_FIND_MBR	(1 << 0)
 #define	FLG_WORK_ADJOIN	(1 << 1)
 
@@ -61,9 +64,11 @@
 #define	STAGGER_RATE_CHR_BLIND	50
 #define	STAGGER_RATE_CHR_DRUNK	50
 
-typedef unsigned long	flg_chr_t;
-typedef unsigned long	flg_stat_t;
-typedef unsigned long	flg_work_t;
+#define	MBR_MAX_N	6
+#define	MBR_N_NOT_JOIN	(-1)
+#define	MBR_NO_POS	(-1)
+
+/**/
 
 typedef enum {
 	CHR_KIND_NULL,
@@ -72,6 +77,7 @@ typedef enum {
 } chr_kind_t;
 
 /* $B<oB2(B */
+
 typedef enum {
 	MAIN_RACE_HUMAN,
 	MAIN_RACE_HALF_ELF,
@@ -101,12 +107,14 @@ typedef struct {
 } race_t;
 
 /* $B@-JL(B */
+
 typedef enum {
 	MALE,
 	FEMALE,
 } sex_t;
 
 /* $BG=NOCM(B */
+
 typedef enum {
 	ABL_KIND_HP,
 	ABL_KIND_MP,
@@ -160,26 +168,31 @@ typedef struct {
 	long	mul_lev, add_lev;
 } lev_to_val_t;
 
-/* $BBQ@-CM(B */
+/* $B%/%i%9(B */
 
 typedef enum {
-	RESI_KIND_KNOC,
-	RESI_KIND_SLAS,
-	RESI_KIND_STIN,
-	RESI_KIND_HEAT,
-	RESI_KIND_COLD,
-	RESI_KIND_WIND,
-	RESI_KIND_ACID,
-	RESI_KIND_ELEC,
-	RESI_KIND_POIS,
-	RESI_KIND_MAX_N,
-} resi_kind_t;
+	CLASS_DFLT_NULL,
+	CLASS_DFLT_FIGHTER,
+	CLASS_DFLT_MONK,
+	CLASS_DFLT_HUNTER,
+	CLASS_DFLT_THIEF,
+	CLASS_DFLT_WIZARD,
+	CLASS_DFLT_SUMMONER,
+	CLASS_DFLT_PRIEST,
+	CLASS_DFLT_SHAMAN,
+	CLASS_DFLT_BARD,
+	CLASS_DFLT_BISHOP,
+} class_dflt_t;
 
 typedef struct {
-	rate_t	n, max;
-} resi_t;
+	n_msg_t	n_name;
+	char	name[CLASS_NAME_MAX_LEN + 1];
+	class_dflt_t	dflt;
+	rate_t	abl_rate[ABL_KIND_MAX_N];
+} class_t;
 
 /* $B%"%/%7%g%s(B */
+
 typedef enum {
 	ACT_KIND_NULL,
 	ACT_KIND_MNSTR_FIGHT,
@@ -235,6 +248,7 @@ typedef struct {
 } act_t;
 
 /* $B%?!<%2%C%H(B */
+
 typedef enum {
 	TRGT_KIND_NULL,
 	TRGT_KIND_MBR,
@@ -250,6 +264,7 @@ typedef enum {
 } trgt_kind_t;
 
 /* $B4V9g$$(B */
+
 typedef enum {
 	DIST_NEAR,
 	DIST_MEDIUM,
@@ -266,6 +281,7 @@ typedef struct {
 } trgt_t;
 
 /* $B<+F0%^!<%/(B */
+
 #define	AUTO_MARK_MAX_N	12
 
 #define	FLG_AUTO_MARK_EDIT_CONT	(1 << 0)
@@ -331,31 +347,6 @@ typedef struct {
 	struct chr_t	*catch_chr;
 } chr_work_t;
 
-#include	"fight.h"
-
-typedef enum {
-	MNSTR_KIND_NULL,
-	MNSTR_KIND_GIANT_BAT,
-	MNSTR_KIND_GIANT_RAT,
-	MNSTR_KIND_MIMIC,
-	MNSTR_KIND_MAX_N
-} mnstr_kind_t;
-
-typedef struct mnstr_tab_t {
-	mnstr_kind_t	mnstr_kind;
-	char	*name;
-	n_msg_t	name_n;
-	long	min_lev, max_lev, sgn_lev;
-	short	group;
-	char	face_mjr, face_mnr;
-	long	abl_lev_max[ABL_KIND_MAX_N];
-	rate_t	resi[RESI_KIND_MAX_N];
-	attack_t	attack[CHR_ATACK_MAX_N + 1];
-	rate_t	def, armor_crtcl, ac;
-	rate_t	move_rate;
-	flg_map_t	flg;
-} mnstr_tab_t;
-
 typedef struct {
 	long	x, y;
 	long	pre_x, pre_y;
@@ -371,6 +362,22 @@ typedef struct {
 	pos_t	chr_pos[MBR_MAX_N];
 } square_t;
 
+typedef struct {
+	mnstr_kind_t	mnstr_kind;
+	char	*name;
+	n_msg_t	name_n;
+	long	min_lev, max_lev, sgn_lev;
+	short	group;
+	char	face_mjr, face_mnr;
+	long	exp;
+	long	abl_lev_max[ABL_KIND_MAX_N];
+	rate_t	resi[RESI_KIND_MAX_N];
+	attack_t	attack[CHR_ATACK_MAX_N + 1];
+	rate_t	def, armor_crtcl, ac;
+	rate_t	move_rate;
+	flg_map_t	flg;
+} mnstr_tab_t;
+
 typedef struct chr_t {
 	struct chr_t	*prev, *next;
 	chr_kind_t	kind;
@@ -397,7 +404,7 @@ typedef struct chr_t {
 	fx_t	fx;
 	fx_data_t	fx_data;
 	mnstr_kind_t	mnstr_kind;
-	struct mnstr_tab_t	*mnstr_tab;
+	mnstr_tab_t	*mnstr_tab;
 	chr_work_t	work;
 } chr_t;
 
