@@ -269,7 +269,6 @@ void	more( flg_msg_t flg, bool_t flg_mul )
 	static long	prev_turn = -1;
 	long	turn;
 	bool_t	flg_ret;
-	long	c;
 	long	y;
 
 	turn = get_turn();
@@ -304,17 +303,7 @@ void	more( flg_msg_t flg, bool_t flg_mul )
 
 	print_str( WIN_MORE_DRAW_MIN_X, y, FLG_PRINT_REV, MSG_MORE );
 
-	while( 1 ){
-		c = get_key( FALSE );
-
-		switch( c ){
-		case CASE_MORE:
-			break;
-		default:
-			continue;
-		}
-		break;
-	}
+	get_key( FALSE );
 
 	print_str( WIN_MORE_DRAW_MIN_X, y, FLG_NULL, MSG_MORE_CLEAR );
 }
@@ -2920,6 +2909,8 @@ void	wait_clock( long frame )
 
 long	read_char( long *p )
 {
+	randm( 1 );
+
 	*p = curs_getch();
 
 	switch( *p ){
