@@ -1,7 +1,7 @@
 #ifndef	__FIGHT_H__
 #define	__FIGHT_H__
 
-//#include	"party.h"
+#include	"resi.h"
 
 #define	CHR_ATACK_MAX_N	3
 
