@@ -1252,187 +1252,187 @@ typedef struct {
 
 	{ NULL, N_MSG_POTION_STONE,
 		POTION_KIND_STONE, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_PARALYZE,
 		POTION_KIND_PARALYZE, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_POISON,
 		POTION_KIND_POISON, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CONFUSION,
 		POTION_KIND_CONFUSION, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_BLIND,
 		POTION_KIND_BLIND, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SLEEP,
 		POTION_KIND_SLEEP, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SILENCE,
 		POTION_KIND_SILENCE, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_FEAR,
 		POTION_KIND_FEAR, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_HALLUCINATION,
 		POTION_KIND_HALLUCINATION, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CHARM,
 		POTION_KIND_CHARM, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_LEV,
 		POTION_KIND_CURE_LEV, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_HP_LIGHT,
 		POTION_KIND_CURE_HP_LIGHT, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_HP_MODERATE,
 		POTION_KIND_CURE_HP_MODERATE, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_HP_SERIOUS,
 		POTION_KIND_CURE_HP_SERIOUS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_HP_MAX,
 		POTION_KIND_CURE_HP_MAX, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_POISON,
 		POTION_KIND_CURE_POISON, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_CURE_STATUS,
 		POTION_KIND_CURE_STATUS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_DETECT_MNSTR,
 		POTION_KIND_DETECT_MNSTR, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_DULLNESS,
 		POTION_KIND_DULLNESS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_FLY,
 		POTION_KIND_FLY, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_POW_UP_HP,
 		POTION_KIND_POW_UP_HP, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SPEED_UP,
 		POTION_KIND_SPEED_UP, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SPEED_DOWN,
 		POTION_KIND_SPEED_DOWN, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_QUICKNESS,
 		POTION_KIND_QUICKNESS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_PHYS,
 		POTION_KIND_RESI_PHYS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_WIND,
 		POTION_KIND_RESI_WIND, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_HEAT,
 		POTION_KIND_RESI_HEAT, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_COLD,
 		POTION_KIND_RESI_COLD, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_ELEC,
 		POTION_KIND_RESI_ELEC, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_ACID,
 		POTION_KIND_RESI_ACID, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_RESI_POIS,
 		POTION_KIND_RESI_POIS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SENSE_INVISIBLE,
 		POTION_KIND_SENSE_INVISIBLE, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SHARPNESS,
 		POTION_KIND_SHARPNESS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_SLOWNESS,
 		POTION_KIND_SLOWNESS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_STRENGTH,
 		POTION_KIND_STRENGTH, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_VANISH,
 		POTION_KIND_VANISH, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_POTION_WEAKNESS,
 		POTION_KIND_WEAKNESS, 80,
-		1, DUN_MAX_LEV, -1, NULL,
+		1, DUN_MAX_LEV, -1, NULL, N_MSG_NULL,
 		FALSE, TRUE },
 
 	{ NULL, N_MSG_NULL,
