@@ -14,8 +14,6 @@
 		'M' - '@': case 'J' - '@'
 #define	CASE_CANCEL	\
 		'G' - '@': case 'H' - '@': case '0': case '\033'
-#define	CASE_MORE	\
-		CASE_CANCEL: case ' ': case ',': case '+'
 #define	CASE_EXEC	\
 		'.': case '5'
 
