@@ -343,7 +343,7 @@ menu_t	ls_menu_main[] = {
 		"/Exec",
 		"<Item>",
 		'X',
-		"+ . , 5",
+		". 5",
 		N_MSG_MENU_EXEC, "",
 		cb_menu_exec, NULL,
 		FLG_NULL,
