@@ -353,12 +353,12 @@ void	make_mnstr_special( long dun_lev, mnstr_t *p )
 		if( !make_item_chest( dun_lev, tmp,
 				get_chest_n( dun_lev ) ) ){
 			free_item( tmp );
-			die_chr( p );
+			die_chr( p, FALSE );
 			break;
 		}
 		if( !put_item( p->x, p->y, 1, tmp, FALSE ) ){
 			free_item( tmp );
-			die_chr( p );
+			die_chr( p, FALSE );
 			break;
 		}
 
@@ -891,7 +891,7 @@ long	add_hp_mnstr( mnstr_t *mnstr, long n )
 		vfx_num( mnstr, add );
 
 	if( mnstr->abl.hp.n <= 0 )
-		die_chr( mnstr );
+		die_chr( mnstr, TRUE );
 
 	return mnstr->abl.hp.n;
 }
@@ -915,8 +915,7 @@ void	set_find_all_mnstr( void )
 	dun = get_dun();
 
 	for( p = mnstr_used.next;
-			(p != NULL) && (p != &mnstr_used);
-			p = p->next ){
+			(p != NULL) && (p != &mnstr_used); p = p->next ){
 		p->flg_chr |= FLG_CHR_FIND;
 		dun->map.chr.flg[p->y][p->x] = p->flg_chr;
 	}
@@ -966,6 +965,19 @@ mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev )
 
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 {
+	if( ls == NULL )
+		return;
+	if( ls->prev == NULL )
+		return;
+	if( ls->next == NULL )
+		return;
+	if( p == NULL )
+		return;
+	if( p->prev == NULL )
+		return;
+	if( p->next == NULL )
+		return;
+
 	p->next->prev = p->prev;
 	p->prev->next = p->next;
 
