@@ -2,11 +2,15 @@
 #define	__MNSTR_H__
 
 #include	"chr.h"
-typedef chr_t	mnstr_t;
+#include	"mnstr_kind.h"
+
+/* $B%b%s%9%?!<(B */
 
 #define	MNSTR_MAX_N	256
 #define	MNSTR_AVE_N	16
 
+typedef chr_t	mnstr_t;
+
 typedef struct {
 	long	x, y;
 } mnstr_null_t;
