@@ -256,6 +256,8 @@
 	{ N_MSG_MBR_DIE,
 		"*** %s was dead ***" },
 
+	{ N_MSG_EXP_PARTY,
+		"All member get %ld EXP" },
 	{ N_MSG_EXP_MBR,
 		"%s gets %ld EXP" },
 	{ N_MSG_LEV_UP,
@@ -2635,6 +2637,11 @@
 		"ۤν()" },
 #endif
 
+/* ANC */
+
+	{ N_MSG_SPELL_NOTHING,
+		"̵" },
+
 /* spell end */
 
 /* color begin */
@@ -3446,6 +3453,11 @@
 	{ N_MSG_GETS_RACE_NAME,
 		"²̾ϤƲ(%ld ʸ)" },
 
+	{ N_MSG_RACE_STR_PUREBRED,
+		"%sν" },
+	{ N_MSG_RACE_STR_MIXED,
+		"%s & %s" },
+
 	{ N_MSG_MBR_DATA_NAME_TTL,
 		"̾  : " },
 	{ N_MSG_MBR_DATA_FACE_TTL,
