@@ -256,6 +256,8 @@
 	{ N_MSG_MBR_DIE,
 		"*** %s ϻ ***" },
 
+	{ N_MSG_EXP_PARTY,
+		"ƥС %ld ηиͤ" },
 	{ N_MSG_EXP_MBR,
 		"%s  %ld ηиͤ" },
 	{ N_MSG_LEV_UP,
