@@ -1460,16 +1460,19 @@ void	exp_party( long exp, bool_t flg_draw )
 	exp_add = exp / n;
 	exp_mod = exp % n;
 
+	if( flg_draw ){
+		print_msg_n( CURS_ATTR_N_FX_MBR_PLUS, FLG_NULL,
+				MSG_EXP_PARTY, exp_add );
+	}
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		if( chk_flg_or( party.mbr[i]->stat, flg ) )
 			continue;
 
-		if( i == mod_n ){
-			exp_chr( pty->mbr[i],
-					exp_add + exp_mod, flg_draw );
-		} else {
-			exp_chr( pty->mbr[i], exp_add, flg_draw);
-		}
+		if( i == mod_n )
+			exp_chr( pty->mbr[i], exp_add + exp_mod, FALSE );
+		else
+			exp_chr( pty->mbr[i], exp_add, FALSE );
 	}
 }
 
@@ -1951,7 +1954,7 @@ long	add_hp_mbr( mbr_t *mbr, long n )
 	}
 
 	if( mbr->abl.hp.n <= 0 )
-		die_chr( mbr );
+		die_chr( mbr, FALSE );
 
 	return mbr->abl.hp.n;
 }
