@@ -77,9 +77,7 @@ void	init_spell( void )
 		spell_tab[k].name = MSG( spell_tab[k].n_name );
 	}
 
-#ifndef	NDEBUG
 	init_spell_debug();
-#endif
 }
 
 /**/
