@@ -5,12 +5,12 @@
 #define	STR_TITLE	"L&L - Labyrinths & Legends :"
 #define	STR_VER_MJR	"2"
 #define	STR_VER_MNR	"1"
-#define	STR_VER_PAT	"8"
+#define	STR_VER_PAT	"10"
 #define	STR_SINCE	"1993"
 #define	STR_LATEST	"2003"
 #define	STR_AUTHOR	"YOSHIMURA Tomohiko"
-#define	STR_HANDLE	"BowKenKen"
-#define	STR_EMAIL_ADR	"jig@mbh.nifty.com"
+#define	STR_HANDLE1	"BowKenKen"
+#define	STR_EMAIL1	"bowkenken@users.sourceforge.jp"
 
 #define	STR_VER_GAME	\
 		STR_VER_MJR "." STR_VER_MNR "." STR_VER_PAT
@@ -22,6 +22,6 @@
 #define	LS_STR_COPYRIGHT	\
 		STR_TITLE, STR_VER_GAME, \
 		STR_SINCE, STR_LATEST, STR_AUTHOR, \
-		STR_EMAIL_ADR, STR_HANDLE
+		STR_EMAIL1, STR_HANDLE1
 
 #endif	/* __VER_H__ */
